Struct amazon_sp_fulfillment_inbound::models::amazon_prep_fees_details::AmazonPrepFeesDetails
source · [−]pub struct AmazonPrepFeesDetails {
pub prep_instruction: Option<PrepInstruction>,
pub fee_per_unit: Option<Box<Amount>>,
}Expand description
AmazonPrepFeesDetails : The fees for Amazon to prep goods for shipment.
Fields
prep_instruction: Option<PrepInstruction>fee_per_unit: Option<Box<Amount>>Implementations
sourceimpl AmazonPrepFeesDetails
impl AmazonPrepFeesDetails
sourcepub fn new() -> AmazonPrepFeesDetails
pub fn new() -> AmazonPrepFeesDetails
The fees for Amazon to prep goods for shipment.